==> haskell-hpack-0.17.0-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.17.0
id: hpack-0.17.0-DCnBHmVvZBc9Bsvsx1MBXX
key: hpack-0.17.0-DCnBHmVvZBc9Bsvsx1MBXX
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
abi: db39c4590f58aa50b4e2725d0d65be31
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hpack-0.17.0
hs-libraries: HShpack-0.17.0-DCnBHmVvZBc9Bsvsx1MBXX
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    yaml-0.8.22-DnTEo5JT71t4IYIZ2cikrl
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.17.0-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.17.0
id: hpack-0.17.0-9Kw43S7pWvrG6fLxyClAYk
key: hpack-0.17.0-9Kw43S7pWvrG6fLxyClAYk
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
abi: 5e7dcc4183a5a3a7baae60e493b722b4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hpack-0.17.0
hs-libraries: HShpack-0.17.0-9Kw43S7pWvrG6fLxyClAYk
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    yaml-0.8.22-ydK5tRWy61L1iyVOvxvB4
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
